summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyutils.h')
-rw-r--r--kmymoney2/mymoney/mymoneyutils.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kmymoney2/mymoney/mymoneyutils.h b/kmymoney2/mymoney/mymoneyutils.h
index 12bb95e..ce0eb42 100644
--- a/kmymoney2/mymoney/mymoneyutils.h
+++ b/kmymoney2/mymoney/mymoneyutils.h
@@ -27,9 +27,9 @@
#include <config.h>
#endif
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqdatetime.h>
+#include <tqvaluelist.h>
#include <kmymoney/export.h>
#if 0
@@ -51,7 +51,7 @@ typedef std::string String;
//typedef for data type to store currency with.
typedef long long DLONG;
-typedef QString String;
+typedef TQString String;
#endif // 0
void timetrace(const char *);
@@ -65,7 +65,7 @@ public:
~MyMoneyUtils() {}
//static function to add the correct file extension at the end of the file name
- static QString getFileExtension(QString strFileName);
+ static TQString getFileExtension(TQString strFileName);
};
@@ -75,13 +75,13 @@ public:
MyMoneyTracer(const char* prettyName);
#define MYMONEYTRACER(a) MyMoneyTracer a(__PRETTY_FUNCTION__)
- MyMoneyTracer(const QString& className, const QString& methodName);
+ MyMoneyTracer(const TQString& className, const TQString& methodName);
~MyMoneyTracer();
/**
* This method allows to trace a printf like formatted text
*
- * @param format format mask
+ * @param format format tqmask
*/
void printf(const char *format, ...) const __attribute__ ((format (__printf__, 2, 3)));
@@ -90,8 +90,8 @@ public:
static void onOff(int onOff);
private:
- QString m_className;
- QString m_memberName;
+ TQString m_className;
+ TQString m_memberName;
static int m_indentLevel;
static int m_onoff;
@@ -100,7 +100,7 @@ private:
#ifdef _CHECK_MEMORY
#include <cstddef>
-#include <qmap.h>
+#include <tqmap.h>
class _CheckMemoryEntry {
public:
@@ -117,10 +117,10 @@ private:
void *m_p;
int m_line;
size_t m_size;
- QString m_file;
+ TQString m_file;
};
-typedef QMap<void *, _CheckMemoryEntry> CheckMemoryTable;
+typedef TQMap<void *, _CheckMemoryEntry> CheckMemoryTable;
typedef void _CheckMemoryOutFunc(const char *);
@@ -170,23 +170,23 @@ KMYMONEY_EXPORT void _CheckMemory_End();
* If the @p date is invalid an empty string will be returned.
*
* @param date const reference to date to be converted
* @return QString containing the converted date
*/
-KMYMONEY_EXPORT QString dateToString(const QDate& date);
+KMYMONEY_EXPORT TQString dateToString(const TQDate& date);
/**
* This function returns a date as QDate object as specified by
* the parameter @p str. @p str must be in Qt::ISODate format.
* If @p str is empty or contains an invalid date, QDate() is
* returned.
*
* @param str date in Qt::ISODate format
- * @return QDate object
+ * @return TQDate object
*/
-KMYMONEY_EXPORT QDate stringToDate(const QString& str);
+KMYMONEY_EXPORT TQDate stringToDate(const TQString& str);
-KMYMONEY_EXPORT QString QStringEmpty(const QString&);
+KMYMONEY_EXPORT TQString TQStringEmpty(const TQString&);
-KMYMONEY_EXPORT unsigned long extractId(const QString& txt);
+KMYMONEY_EXPORT unsigned long extractId(const TQString& txt);
#endif
@@ -170,23 +170,23 @@ KMYMONEY_EXPORT void _CheckMemory_End();
*
* @param date const reference to date to be converted
- * @return QString containing the converted date
+ * @return TQString containing the converted date
*/
@@ -170,23 +170,23 @@ KMYMONEY_EXPORT void _CheckMemory_End();
/**
- * This function returns a date as QDate object as specified by
+ * This function returns a date as TQDate object as specified by
* the parameter @p str. @p str must be in Qt::ISODate format.
@@ -170,23 +170,23 @@ KMYMONEY_EXPORT void _CheckMemory_End();
* the parameter @p str. @p str must be in Qt::ISODate format.
- * If @p str is empty or contains an invalid date, QDate() is
+ * If @p str is empty or contains an invalid date, TQDate() is
* returned.
*